@@ -1,5 +1,7 @@
 """UI tests for the appalerts app"""
 
+import time
+
 from django.urls import reverse
 
 from selenium.common.exceptions import NoSuchElementException
@@ -47,7 +49,11 @@ class TestListView(TestAlertUIBase):
         ]
         url = reverse('appalerts:list')
         self.assert_element_count(
-            expected, url, 'sodar-app-alert-item', 'class'
+            expected,
+            url,
+            'alert alert-info sodar-app-alert-item',
+            'class',
+            exact=True,
         )
 
     def test_alert_dismiss(self):
@@ -251,3 +257,21 @@ class TestTitlebarBadge(TestAlertUIBase):
         )
         self.assertEqual(alert_count.text, '1')
         self.assertEqual(alert_legend.text, 'alert')
+
+    def test_alert_dismiss_all(self):
+        """Test dismissing all alerts for the user"""
+        self.assertEqual(AppAlert.objects.filter(active=True).count(), 2)
+
+        url = reverse('home')
+        self.login_and_redirect(self.regular_user, url)
+
+        self.selenium.find_element_by_id(
+            'sodar-app-alert-badge-btn-dismiss'
+        ).click()
+        WebDriverWait(self.selenium, self.wait_time).until(
+            ec.invisibility_of_element_located(
+                (By.CLASS_NAME, 'sodar-app-alert-legend')
+            )
+        )
+        time.sleep(2)  # HACK: Timing issue, must wait just in case
+        self.assertEqual(AppAlert.objects.filter(active=True).count(), 0)
