@@ -1,17 +1,27 @@
 """REST API view tests for the filesfolders app"""
+
 import json
 
 from django.urls import reverse
 from test_plus.test import APITestCase
 
 # Projectroles dependency
+from projectroles.models import SODAR_CONSTANTS
 from projectroles.tests.test_views_api import SODARAPIViewTestMixin
-from projectroles.views_api import CORE_API_MEDIA_TYPE, CORE_API_DEFAULT_VERSION
+from projectroles.views_api import (
+    CORE_API_MEDIA_TYPE,
+    CORE_API_DEFAULT_VERSION,
+    INVALID_PROJECT_TYPE_MSG,
+)
 
 from filesfolders.tests.test_views import ZIP_PATH_NO_FILES, TestViewsBaseMixin
 from filesfolders.models import Folder, File, HyperLink
 
 
+# SODAR constants
+PROJECT_TYPE_CATEGORY = SODAR_CONSTANTS['PROJECT_TYPE_CATEGORY']
+
+# Local constants
 INVALID_UUID = '11111111-1111-1111-1111-111111111111'
 
 
@@ -48,10 +58,7 @@ class TestFolderListCreateAPIView(TestFilesfoldersAPIViewsBase):
                 kwargs={'project': self.project.sodar_uuid},
             )
         )
-
-        # Assert response
         self.assertEqual(response.status_code, 200, msg=response.data)
-
         expected = [
             {
                 'name': self.folder.name,
@@ -125,6 +132,26 @@ class TestFolderListCreateAPIView(TestFilesfoldersAPIViewsBase):
         }
         self.assertEqual(json.loads(response.content), expected)
 
+    def test_create_in_category(self):
+        """Test creation of new folder in a category (should fail)"""
+        category = self._make_project(
+            'TestCategory', PROJECT_TYPE_CATEGORY, None
+        )
+        self._make_assignment(category, self.user, self.role_owner)
+        response = self.request_knox(
+            reverse(
+                'filesfolders:api_folder_list_create',
+                kwargs={'project': category.sodar_uuid},
+            ),
+            method='POST',
+            data=self.folder_data,
+        )
+        self.assertEqual(response.status_code, 403, msg=response.data)
+        self.assertEqual(
+            str(response.data['detail']),
+            INVALID_PROJECT_TYPE_MSG.format(project_type=PROJECT_TYPE_CATEGORY),
+        )
+
 
 class TestFolderRetrieveUpdateDestroyAPIView(TestFilesfoldersAPIViewsBase):
     """Tests for the FolderRetrieveUpdateDestroyAPIView class"""
@@ -320,6 +347,27 @@ class TestFileListCreateAPIView(TestFilesfoldersAPIViewsBase):
         expected.pop('file')
         self.assertEqual(json.loads(response.content), expected)
 
+    def test_create_in_category(self):
+        """Test creation of new file in a category (should fail)"""
+        category = self._make_project(
+            'TestCategory', PROJECT_TYPE_CATEGORY, None
+        )
+        self._make_assignment(category, self.user, self.role_owner)
+        response = self.request_knox(
+            reverse(
+                'filesfolders:api_file_list_create',
+                kwargs={'project': category.sodar_uuid},
+            ),
+            method='POST',
+            format='multipart',
+            data=self.file_data,
+        )
+        self.assertEqual(response.status_code, 403, msg=response.data)
+        self.assertEqual(
+            str(response.data['detail']),
+            INVALID_PROJECT_TYPE_MSG.format(project_type=PROJECT_TYPE_CATEGORY),
+        )
+
 
 class TestFileRetrieveUpdateDestroyAPIView(TestFilesfoldersAPIViewsBase):
     """Tests for the FileRetrieveUpdateDestroyAPIView class"""
@@ -554,6 +602,26 @@ class TestHyperLinkListCreateAPIView(TestFilesfoldersAPIViewsBase):
         }
         self.assertEqual(json.loads(response.content), expected)
 
+    def test_create_in_category(self):
+        """Test creation of new hyperlink in a category (should fail)"""
+        category = self._make_project(
+            'TestCategory', PROJECT_TYPE_CATEGORY, None
+        )
+        self._make_assignment(category, self.user, self.role_owner)
+        response = self.request_knox(
+            reverse(
+                'filesfolders:api_hyperlink_list_create',
+                kwargs={'project': category.sodar_uuid},
+            ),
+            method='POST',
+            data=self.hyperlink_data,
+        )
+        self.assertEqual(response.status_code, 403, msg=response.data)
+        self.assertEqual(
+            str(response.data['detail']),
+            INVALID_PROJECT_TYPE_MSG.format(project_type=PROJECT_TYPE_CATEGORY),
+        )
+
 
 class TestHyperLinkRetrieveUpdateDestroyAPIView(TestFilesfoldersAPIViewsBase):
     """Tests for the HyperLinkRetrieveUpdateDestroyAPIView class"""
