@@ -139,19 +139,6 @@ class TestCommonTemplateTags(TestTemplateTagsBase):
         )
         self.assertEqual(c_tags.get_user_by_username('NON_EXISTING_USER'), None)
 
-    def test_get_plugin_name_by_id(self):
-        """Test get_plugin_name_by_id()"""
-        self.assertEqual(
-            c_tags.get_plugin_name_by_id(
-                self.setting_filesfolders.app_plugin_id
-            ),
-            'filesfolders',
-        )
-
-    def test_get_plugin_name_by_id_no_id(self):
-        """Test get_plugin_name_by_id()"""
-        self.assertEqual(c_tags.get_plugin_name_by_id(None), 'projectroles')
-
     def test_get_django_setting(self):
         """Test get_django_setting()"""
         ret = c_tags.get_django_setting('PROJECTROLES_BROWSER_WARNING')
@@ -302,6 +289,7 @@ class TestCommonTemplateTags(TestTemplateTagsBase):
             c_tags.highlight_search_term(item, term),
             'Some <span class="sodar-search-highlight">Highlight</span>ed Text',
         )
+        self.assertEqual(c_tags.highlight_search_term(item, ''), item)
 
     def test_get_info_link(self):
         """Test get_info_link()"""
@@ -580,18 +568,6 @@ class TestProjectrolesTemplateTags(TestTemplateTagsBase):
 
     # TODO: Test get_pr_link_state()
 
-    def test_get_star(self):
-        """Test get_star()"""
-        user_no_roles = self.make_user('user_no_roles')
-        self.assertEqual(tags.get_star(self.project, self.user), '')
-        set_tag_state(self.project, self.user, name=PROJECT_TAG_STARRED)
-        self.assertEqual(
-            tags.get_star(self.project, self.user),
-            '<i class="iconify text-warning sodar-tag-starred" '
-            'data-icon="mdi:star"></i>',
-        )
-        self.assertEqual(tags.get_star(self.project, user_no_roles), '')
-
     def test_get_help_highlight(self):
         """Test get_help_highlight()"""
         self.assertEqual(
