@@ -298,9 +298,7 @@ class TestUIBase(
         field_user.send_keys(user.username)
         field_pass = self.selenium.find_element_by_id('sodar-login-password')
         field_pass.send_keys('password')
-        self.selenium.find_element_by_xpath(
-            '//button[contains(., "Login")]'
-        ).click()
+        self.selenium.find_element_by_id('sodar-login-submit').click()
         # Wait for redirect
         WebDriverWait(self.selenium, self.wait_time).until(
             ec.presence_of_element_located(
@@ -355,6 +353,7 @@ class TestUIBase(
         search_string,
         attribute='id',
         path='//',
+        exact=False,
         wait_elem=None,
         wait_loc=DEFAULT_WAIT_LOC,
     ):
@@ -366,35 +365,33 @@ class TestUIBase(
         :param url: URL to test (string)
         :param search_string: ID substring of element (string)
         :param attribute: Attribute to search for (string, default=id)
+        :param path: Path for searching (string, default="//")
+        :param exact: Exact match if True (boolean, default=False)
         :param wait_elem: Wait for existence of an element (string, optional)
         :param wait_loc: Locator of optional wait element (string, corresponds
                          to selenium "By" class members)
         """
         for e in expected:
             expected_user = e[0]  # Just to clarify code
-            expected_count = e[1]
-
             self.login_and_redirect(expected_user, url, wait_elem, wait_loc)
 
+            xpath = '{}*[@{}="{}"]' if exact else '{}*[contains(@{}, "{}")]'
+            expected_count = e[1]
+
             if expected_count > 0:
                 self.assertEqual(
                     len(
                         self.selenium.find_elements_by_xpath(
-                            '{}*[contains(@{}, "{}")]'.format(
-                                path, attribute, search_string
-                            )
+                            xpath.format(path, attribute, search_string)
                         )
                     ),
                     expected_count,
                     'expected_user={}'.format(expected_user),
                 )
-
             else:
                 with self.assertRaises(NoSuchElementException):
                     self.selenium.find_element_by_xpath(
-                        '{}*[contains(@{}, "{}")]'.format(
-                            path, attribute, search_string
-                        )
+                        xpath.format(path, attribute, search_string)
                     )
 
     def assert_element_set(
