@@ -9,7 +9,11 @@ from django.core.exceptions import ImproperlyConfigured
 from django.utils import timezone
 
 from rest_framework import serializers
-from rest_framework.exceptions import APIException, NotFound, PermissionDenied
+from rest_framework.exceptions import (
+    APIException,
+    NotFound,
+    PermissionDenied,
+)
 from rest_framework.generics import (
     CreateAPIView,
     ListAPIView,
@@ -54,6 +58,10 @@ from projectroles.views import (
 )
 
 
+User = auth.get_user_model()
+app_settings = AppSettingAPI()
+
+
 # SODAR constants
 PROJECT_TYPE_PROJECT = SODAR_CONSTANTS['PROJECT_TYPE_PROJECT']
 PROJECT_TYPE_CATEGORY = SODAR_CONSTANTS['PROJECT_TYPE_CATEGORY']
@@ -62,7 +70,6 @@ PROJECT_ROLE_DELEGATE = SODAR_CONSTANTS['PROJECT_ROLE_DELEGATE']
 PROJECT_ROLE_CONTRIBUTOR = SODAR_CONSTANTS['PROJECT_ROLE_CONTRIBUTOR']
 PROJECT_ROLE_GUEST = SODAR_CONSTANTS['PROJECT_ROLE_GUEST']
 
-
 # API constants for external SODAR Core sites
 SODAR_API_MEDIA_TYPE = getattr(
     settings, 'SODAR_API_MEDIA_TYPE', 'application/UNDEFINED+json'
@@ -91,14 +98,15 @@ CORE_API_ALLOWED_VERSIONS = [
     '0.10.2',
     '0.10.3',
     '0.10.4',
+    '0.10.5',
+    '0.10.6',
+    '0.10.7',
 ]
 
-
-# Access Django user model
-User = auth.get_user_model()
-
-# App Settings
-app_settings = AppSettingAPI()
+# Local constants
+INVALID_PROJECT_TYPE_MSG = (
+    'Project type "{project_type}" not allowed for this API view'
+)
 
 
 # Permission / Versioning / Renderer Classes -----------------------------------
@@ -115,6 +123,9 @@ class SODARAPIProjectPermission(ProjectAccessMixin, BasePermission):
 
     Requires implementing either permission_required or
     get_permission_required() in the view.
+
+    Project type can be restricted to PROJECT_TYPE_CATEGORY or
+    PROJECT_TYPE_PROJECT by setting the project_type attribute in the view.
     """
 
     def has_permission(self, request, view):
@@ -130,6 +141,19 @@ class SODARAPIProjectPermission(ProjectAccessMixin, BasePermission):
         if not project:
             raise NotFound()
 
+        # Restrict project type
+        project_type = getattr(view, 'project_type', None)
+        p_types = [PROJECT_TYPE_CATEGORY, PROJECT_TYPE_PROJECT]
+        if project_type and project_type not in p_types:
+            raise ImproperlyConfigured(
+                'Invalid value "{}" for project_type, accepted values: '
+                '{}'.format(project_type, ', '.join(p_types))
+            )
+        elif project_type and project_type != project.type:
+            raise PermissionDenied(
+                INVALID_PROJECT_TYPE_MSG.format(project_type=project.type)
+            )
+
         owner_or_delegate = project.is_owner_or_delegate(request.user)
 
         if not (
@@ -217,9 +241,13 @@ class SODARAPIBaseProjectMixin(ProjectAccessMixin, SODARAPIBaseMixin):
     """
     API view mixin for the base DRF APIView class with project permission
     checking, but without serializers and other generic view functionality.
+
+    Project type can be restricted to PROJECT_TYPE_CATEGORY or
+    PROJECT_TYPE_PROJECT by setting the project_type attribute in the view.
     """
 
     permission_classes = [SODARAPIProjectPermission]
+    project_type = None
 
 
 class APIProjectContextMixin(ProjectAccessMixin):
@@ -839,7 +867,7 @@ class RemoteProjectGetAPIView(CoreAPIBaseMixin, APIView):
         except RemoteSite.DoesNotExist:
             return Response('Remote site not found, unauthorized', status=401)
 
-        sync_data = remote_api.get_target_data(target_site)
+        sync_data = remote_api.get_source_data(target_site)
 
         # Update access date for target site remote projects
         target_site.projects.all().update(date_access=timezone.now())
