@@ -1,4 +1,5 @@
 """Timeline API for adding and updating events"""
+import logging
 import re
 
 from django.contrib.auth import get_user_model
@@ -7,7 +8,7 @@ from django.utils.text import Truncator
 
 # Projectroles dependency
 from projectroles.models import Project, RemoteSite
-from projectroles.plugins import ProjectAppPluginPoint
+from projectroles.plugins import get_app_plugin
 from projectroles.templatetags.projectroles_common_tags import get_user_html
 from projectroles.utils import get_app_names
 
@@ -18,35 +19,57 @@ from timeline.models import (
 )
 
 
+logger = logging.getLogger(__name__)
+User = get_user_model()
+
+
 # Local variables
 APP_NAMES = get_app_names()
 LABEL_MAX_WIDTH = 32
-
-# Access Django user model
-User = get_user_model()
+UNKNOWN_LABEL = '(unknown)'
 
 
 class TimelineAPI:
     """Timeline backend API to be used by Django apps."""
 
-    # Helpers ------------------------------------------------------------------
+    # Internal Helpers ---------------------------------------------------------
 
-    @staticmethod
-    def _get_label(label):
+    @classmethod
+    def _get_label(cls, label):
         """Format label to be displayed"""
         if not {' ', '-'}.intersection(label):
             return Truncator(label).chars(LABEL_MAX_WIDTH)
         return label
 
-    @staticmethod
-    def _get_not_found_label(ref_obj, history_link):
-        """Get label for object which is not found in db"""
-        return '<span class="text-danger">{}</span> {}'.format(
-            TimelineAPI._get_label(ref_obj.name), history_link
+    @classmethod
+    def _get_history_link(cls, ref_obj):
+        """Return history link HTML for event object reference"""
+        url_name = 'timeline:list_object_site'
+        url_kwargs = {
+            'object_model': ref_obj.object_model,
+            'object_uuid': ref_obj.object_uuid,
+        }
+        if ref_obj.event.project:
+            url_name = 'timeline:list_object'
+            url_kwargs['project'] = ref_obj.event.project.sodar_uuid
+        history_url = reverse(url_name, kwargs=url_kwargs)
+        return (
+            '<a href="{}" class="sodar-tl-object-link">'
+            '<i class="iconify" '
+            'data-icon="mdi:clock-time-eight-outline"></i></a>'.format(
+                history_url
+            )
         )
 
-    @staticmethod
-    def _get_project_desc(ref_obj, request=None):
+    @classmethod
+    def _get_not_found_label(cls, ref_obj):
+        """Get label for object which is not found in the database"""
+        return '<span class="text-danger">{}</span> {}'.format(
+            cls._get_label(ref_obj.name), cls._get_history_link(ref_obj)
+        )
+
+    @classmethod
+    def _get_project_desc(cls, ref_obj, request=None):
         """Get description HTML for special case: Project model"""
         project = Project.objects.filter(sodar_uuid=ref_obj.object_uuid).first()
         if (
@@ -54,20 +77,21 @@ class TimelineAPI:
             and request
             and request.user.has_perm('projectroles.view_project', project)
         ):
-            return '<a href="{}">{}</a>'.format(
+            return '<a class="sodar-tl-project-link" href="{}">{}</a>'.format(
                 reverse(
-                    'projetroles:detail', kwargs={'project': project.sodar_uuid}
+                    'projectroles:detail',
+                    kwargs={'project': project.sodar_uuid},
                 ),
-                TimelineAPI._get_label(project.title),
+                cls._get_label(project.title),
             )
         elif project:
             return '<span class="text-danger">{}</span>'.format(
-                TimelineAPI._get_label(project.title)
+                cls._get_label(project.title)
             )
         return ref_obj.name
 
-    @staticmethod
-    def _get_remote_site_desc(ref_obj, history_link, request=None):
+    @classmethod
+    def _get_remote_site_desc(cls, ref_obj, request=None):
         """Get description HTML for special case: RemoteSite model"""
         site = RemoteSite.objects.filter(sodar_uuid=ref_obj.object_uuid).first()
         if site and request and request.user.is_superuser:
@@ -77,16 +101,86 @@ class TimelineAPI:
                     kwargs={'remotesite': site.sodar_uuid},
                 ),
                 site.name,
-                history_link,
+                cls._get_history_link(ref_obj),
             )
         elif site:
             return site.name
-        return TimelineAPI._get_not_found_label(ref_obj, history_link)
+        return cls._get_not_found_label(ref_obj)
+
+    @classmethod
+    def _get_ref_description(cls, event, ref_label, app_plugin, request):
+        """
+        Get reference object description for event description, or unknown label
+        if not found.
+
+        :param event: ProjectEvent object
+        :param ref_label: Label for the reference object (string)
+        :param app_plugin: App plugin or None
+        :param request: Request object or None
+        :return: String (contains HTML)
+        """
+        # Special case: Extra data reference
+        if ref_label.startswith('extra-'):
+            desc = app_plugin.get_extra_data_link(event.extra_data, ref_label)
+            return desc if desc else UNKNOWN_LABEL
+
+        # Get object reference
+        try:
+            ref_obj = ProjectEventObjectRef.objects.get(
+                event=event, label=ref_label
+            )
+        except ProjectEventObjectRef.DoesNotExist:
+            return UNKNOWN_LABEL
+
+        # Special case: User model
+        if ref_obj.object_model == 'User':
+            try:
+                user = User.objects.get(sodar_uuid=ref_obj.object_uuid)
+                return '{} {}'.format(
+                    get_user_html(user), cls._get_history_link(ref_obj)
+                )
+            except User.DoesNotExist:
+                return UNKNOWN_LABEL
+
+        # Special case: Project model
+        elif ref_obj.object_model == 'Project':
+            return cls._get_project_desc(ref_obj, request)
+
+        # Special case: RemoteSite model
+        elif ref_obj.object_model == 'RemoteSite':
+            return cls._get_remote_site_desc(ref_obj, request)
+
+        # Special case: projectroles app
+        elif event.app == 'projectroles':
+            return cls._get_not_found_label(ref_obj)
+
+        # Apps with plugins
+        else:
+            try:
+                link_data = app_plugin.get_object_link(
+                    ref_obj.object_model, ref_obj.object_uuid
+                )
+            except Exception:
+                link_data = None
+            if link_data:
+                return '<a href="{}" {}>{}</a> {}'.format(
+                    link_data['url'],
+                    (
+                        'target="_blank"'
+                        if 'blank' in link_data and link_data['blank'] is True
+                        else ''
+                    ),
+                    cls._get_label(link_data['label']),
+                    cls._get_history_link(ref_obj),
+                )
+            else:
+                return cls._get_not_found_label(ref_obj)
 
     # API functions ------------------------------------------------------------
 
-    @staticmethod
+    @classmethod
     def add_event(
+        cls,
         project,
         app_name,
         user,
@@ -102,8 +196,8 @@ class TimelineAPI:
         Create and save a timeline event.
 
         :param project: Project object or None
-        :param app_name: ID string of app from which event was invoked (NOTE:
-            should correspond to member "name" in app plugin!)
+        :param app_name: Name of app from which event was invoked (must
+            correspond to "name" attribute of app plugin)
         :param user: User invoking the event or None
         :param event_name: Event ID string (must match schema)
         :param description: Description of status change (may include {object
@@ -122,7 +216,6 @@ class TimelineAPI:
                     app_name, ', '.join(x for x in APP_NAMES)
                 )
             )
-
         if status_type and status_type not in EVENT_STATUS_TYPES:
             raise ValueError(
                 'Unknown status type "{}" (valid types: {})'.format(
@@ -154,8 +247,8 @@ class TimelineAPI:
 
         return event
 
-    @staticmethod
-    def get_project_events(project, classified=False):
+    @classmethod
+    def get_project_events(cls, project, classified=False):
         """
         Return timeline events for a project.
 
@@ -168,8 +261,8 @@ class TimelineAPI:
             events = events.filter(classified=False)
         return events
 
-    @staticmethod
-    def get_event_description(event, request=None):
+    @classmethod
+    def get_event_description(cls, event, request=None):
         """
         Return the description of a timeline event as HTML.
 
@@ -178,101 +271,42 @@ class TimelineAPI:
         :return: String (contains HTML)
         """
         desc = event.description
-        unknown_label = '(unknown)'
-        refs = {}
         ref_ids = re.findall('{\'?(.*?)\'?}', desc)
         if len(ref_ids) == 0:
             return event.description
 
+        refs = {}
+        app_plugin = None
+
+        if event.app != 'projectroles':
+            app_plugin = get_app_plugin(event.app)
+            if not app_plugin:
+                msg = 'Plugin not found: {}'.format(event.app)
+                logger.error(msg + ' (UUID={})'.format(event.sodar_uuid))
+                return (
+                    '<span class="sodar-tl-plugin-error text-danger">'
+                    '{}</span>'.format(msg)
+                )
+
+        # Get links for object references
         for r in ref_ids:
-            # Get reference object or return an unknown label if not found
-            if r.startswith('extra-'):
-                app_plugin = ProjectAppPluginPoint.get_plugin(name=event.app)
-                refs[r] = app_plugin.get_extra_data_link(event.extra_data, r)
-                continue
-            try:
-                ref_obj = ProjectEventObjectRef.objects.get(
-                    event=event, label=r
-                )
-            except ProjectEventObjectRef.DoesNotExist:
-                refs[r] = unknown_label
-                continue
-
-            # Get history link
-            url_name = 'timeline:list_object_site'
-            url_kwargs = {
-                'object_model': ref_obj.object_model,
-                'object_uuid': ref_obj.object_uuid,
-            }
-            if event.project:
-                url_name = 'timeline:list_object'
-                url_kwargs['project'] = event.project.sodar_uuid
-            history_url = reverse(url_name, kwargs=url_kwargs)
-            history_link = (
-                '<a href="{}" class="sodar-tl-object-link">'
-                '<i class="iconify" '
-                'data-icon="mdi:clock-time-eight-outline"></i></a>'.format(
-                    history_url
-                )
-            )
-
-            # Special case: User model
-            if ref_obj.object_model == 'User':
-                try:
-                    user = User.objects.get(sodar_uuid=ref_obj.object_uuid)
-                    refs[r] = '{} {}'.format(get_user_html(user), history_link)
-                except User.DoesNotExist:
-                    refs[r] = unknown_label
-
-            # Special case: Project model
-            elif ref_obj.object_model == 'Project':
-                refs[r] = TimelineAPI._get_project_desc(ref_obj, request)
-
-            # Special case: RemoteSite model
-            elif ref_obj.object_model == 'RemoteSite':
-                refs[r] = TimelineAPI._get_remote_site_desc(
-                    ref_obj, history_link, request
-                )
-
-            # Special case: projectroles app
-            elif event.app == 'projectroles':
-                refs[r] = TimelineAPI._get_not_found_label(
-                    ref_obj, history_link
-                )
-
-            # Apps with plugins
-            else:
-                app_plugin = ProjectAppPluginPoint.get_plugin(name=event.app)
-                try:
-                    link_data = app_plugin.get_object_link(
-                        ref_obj.object_model, ref_obj.object_uuid
-                    )
-                except Exception:
-                    link_data = None
-                if link_data:
-                    refs[r] = '<a href="{}" {}>{}</a> {}'.format(
-                        link_data['url'],
-                        (
-                            'target="_blank"'
-                            if 'blank' in link_data
-                            and link_data['blank'] is True
-                            else ''
-                        ),
-                        TimelineAPI._get_label(link_data['label']),
-                        history_link,
-                    )
-                else:
-                    refs[r] = TimelineAPI._get_not_found_label(
-                        ref_obj, history_link
-                    )
+            refs[r] = cls._get_ref_description(event, r, app_plugin, request)
 
         try:
             return event.description.format(**refs)
         except Exception as ex:  # Dispaly exception instead of crashing
-            return '{}: {}'.format(ex.__class__.__name__, ex)
+            logger.error(
+                'Error formatting event description: {} (UUID={})'.format(
+                    ex, event.sodar_uuid
+                )
+            )
+            return (
+                '<span class="sodar-tl-format-error text-danger">'
+                '{}: {}</span>'.format(ex.__class__.__name__, ex)
+            )
 
-    @staticmethod
-    def get_object_url(obj, project=None):
+    @classmethod
+    def get_object_url(cls, obj, project=None):
         """
         Return the URL for a timeline event object history.
 
@@ -290,8 +324,8 @@ class TimelineAPI:
             url_kwargs['project'] = project.sodar_uuid
         return reverse(url_name, kwargs=url_kwargs)
 
-    @staticmethod
-    def get_object_link(obj, project=None):
+    @classmethod
+    def get_object_link(cls, obj, project=None):
         """
         Return an inline HTML icon link for a timeline event object history.
 
@@ -302,11 +336,11 @@ class TimelineAPI:
         return (
             '<a href="{}" class="sodar-tl-object-link">'
             '<i class="iconify" data-icon="mdi:clock-time-eight-outline"></i>'
-            '</a>'.format(TimelineAPI.get_object_url(obj, project))
+            '</a>'.format(cls.get_object_url(obj, project))
         )
 
-    @staticmethod
-    def get_models():
+    @classmethod
+    def get_models(cls):
         """
         Return project event model classes for custom/advanced queries.
 
